// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See the LICENSE file in builder/azure for license information.

package constants

// complete flags
const (
	AuthorizedKey string = "authorizedKey"
	Certificate   string = "certificate"
	Error         string = "error"
	PrivateKey    string = "privateKey"
	SSHHost       string = "sshHost"
	Thumbprint    string = "thumbprint"
	Ui            string = "ui"
)
const (
	ArmCaptureTemplate                 string = "arm.CaptureTemplate"
	ArmComputeName                     string = "arm.ComputeName"
	ArmImageParameters                 string = "arm.ImageParameters"
	ArmCertificateUrl                  string = "arm.CertificateUrl"
	ArmDeploymentName                  string = "arm.DeploymentName"
	ArmNicName                         string = "arm.NicName"
	ArmKeyVaultName                    string = "arm.KeyVaultName"
	ArmLocation                        string = "arm.Location"
	ArmOSDiskVhd                       string = "arm.OSDiskVhd"
	ArmPublicIPAddressName             string = "arm.PublicIPAddressName"
	ArmResourceGroupName               string = "arm.ResourceGroupName"
	ArmIsResourceGroupCreated          string = "arm.IsResourceGroupCreated"
	ArmStorageAccountName              string = "arm.StorageAccountName"
	ArmTags                            string = "arm.Tags"
	ArmVirtualMachineCaptureParameters string = "arm.VirtualMachineCaptureParameters"

	ArmIsManagedImage                string = "arm.IsManagedImage"
	ArmManagedImageResourceGroupName string = "arm.ManagedImageResourceGroupName"
	ArmManagedImageLocation          string = "arm.ManagedImageLocation"
	ArmManagedImageName              string = "arm.ManagedImageName"
)
